.. raw:: html

    <style> .red {color:red} </style>
    <style> .blue {color:blue} </style>
    <style> .green {color:green} </style>
    <style> .cyan {color:cyan} </style>
    <style> .magenta {color:magenta} </style>
    <style> .orange {color:orange} </style>
    <style> .brown {color:brown} </style>

.. role:: red
.. role:: blue
.. role:: green
.. role:: cyan
.. role:: magenta
.. role:: orange
.. role:: brown

.. _v4blocks:

The following classes implement different MDF version4 blocks.

AttachmentBlock Class
=====================
.. autoclass:: asammdf.blocks.v4_blocks.AttachmentBlock
    :members:

Channel Class
=============
.. autoclass:: asammdf.blocks.v4_blocks.Channel
    :members:

ChannelConversion Class
=======================
.. autoclass:: asammdf.blocks.v4_blocks.ChannelConversion
    :members:

ChannelGroup Class
==================
.. autoclass:: asammdf.blocks.v4_blocks.ChannelGroup
    :members:

DataGroup Class
===============
.. autoclass:: asammdf.blocks.v4_blocks.DataGroup
    :members:

DataList Class
==============
.. autoclass:: asammdf.blocks.v4_blocks.DataList
    :members:

DataBlock Class
===============
.. autoclass:: asammdf.blocks.v4_blocks.DataBlock
    :members:

FileIdentificationBlock Class
=============================
.. autoclass:: asammdf.blocks.v4_blocks.FileIdentificationBlock
    :members:

HeaderBlock Class
=================
.. autoclass:: asammdf.blocks.v4_blocks.HeaderBlock
    :members:

SourceInformation Class
=======================
.. autoclass:: asammdf.blocks.v4_blocks.SourceInformation
    :members:

FileHistory Class
=================
.. autoclass:: asammdf.blocks.v4_blocks.FileHistory
    :members:

TextBlock Class
===============
.. autoclass:: asammdf.blocks.v4_blocks.TextBlock
    :members:

EventBlock Class
================
.. autoclass:: asammdf.blocks.v4_blocks.EventBlock
    :members:
